From khali@linux-fr.org Wed Jul 27 12:28:48 2005
Date: Wed, 27 Jul 2005 21:27:26 +0200
From: Jean Delvare <khali@linux-fr.org>
To: Greg KH <greg@kroah.com>
Cc: Marcelo Feitoza Parisi <marcelo@feitoza.com.br>
Subject: I2C: use time_after in 3 chip drivers
Message-Id: <20050727212726.5d8037e2.khali@linux-fr.org>


A few i2c drivers were not updated to use time_after() yet.

Signed-off-by: Marcelo Feitoza Parisi <marcelo@feitoza.com.br>
Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/hwmon/atxp1.c   |    5 ++---
 drivers/hwmon/fscpos.c  |    4 ++--
 drivers/hwmon/gl520sm.c |    4 ++--
 3 files changed, 6 insertions(+), 7 deletions(-)

--- gregkh-2.6.orig/drivers/hwmon/atxp1.c	2005-07-27 23:18:12.000000000 -0700
+++ gregkh-2.6/drivers/hwmon/atxp1.c	2005-07-27 23:20:20.000000000 -0700
@@ -21,6 +21,7 @@
 #include <linux/kernel.h>
 #include <linux/init.h>
 #include <linux/module.h>
+#include <linux/jiffies.h>
 #include <linux/i2c.h>
 #include <linux/i2c-sensor.h>
 #include <linux/i2c-vid.h>
@@ -80,9 +81,7 @@
 
 	down(&data->update_lock);
 
-	if ((jiffies - data->last_updated > HZ) ||
-	    (jiffies < data->last_updated) ||
-	    !data->valid) {
+	if (time_after(jiffies, data->last_updated + HZ) || !data->valid) {
 
 		/* Update local register data */
 		data->reg.vid = i2c_smbus_read_byte_data(client, ATXP1_VID);
--- gregkh-2.6.orig/drivers/hwmon/fscpos.c	2005-07-27 23:18:12.000000000 -0700
+++ gregkh-2.6/drivers/hwmon/fscpos.c	2005-07-27 23:20:20.000000000 -0700
@@ -32,6 +32,7 @@
 
 #include <linux/module.h>
 #include <linux/slab.h>
+#include <linux/jiffies.h>
 #include <linux/i2c.h>
 #include <linux/i2c-sensor.h>
 #include <linux/init.h>
@@ -572,8 +573,7 @@
 
 	down(&data->update_lock);
 
-	if ((jiffies - data->last_updated > 2 * HZ) ||
-			(jiffies < data->last_updated) || !data->valid) {
+	if (time_after(jiffies, data->last_updated + 2 * HZ) || !data->valid) {
 		int i;
 
 		dev_dbg(&client->dev, "Starting fscpos update\n");
--- gregkh-2.6.orig/drivers/hwmon/gl520sm.c	2005-07-27 23:18:12.000000000 -0700
+++ gregkh-2.6/drivers/hwmon/gl520sm.c	2005-07-27 23:20:20.000000000 -0700
@@ -24,6 +24,7 @@
 #include <linux/module.h>
 #include <linux/init.h>
 #include <linux/slab.h>
+#include <linux/jiffies.h>
 #include <linux/i2c.h>
 #include <linux/i2c-sensor.h>
 #include <linux/i2c-vid.h>
@@ -678,8 +679,7 @@
 
 	down(&data->update_lock);
 
-	if ((jiffies - data->last_updated > 2 * HZ) ||
-	    (jiffies < data->last_updated) || !data->valid) {
+	if (time_after(jiffies, data->last_updated + 2 * HZ) || !data->valid) {
 
 		dev_dbg(&client->dev, "Starting gl520sm update\n");
 
